### Définition de contraintes topologiques

Une règle topologique définit les relations spatiales entre des entités vectorielles connectées ou adjacentes. La topologie décrit les relations de connexion entre les arcs et d’adjacence entre les polygones. L’intérêt de la topologie dans les bases de données SIG est de supprimer les redondances dans la description géométrique des entités et d’accélérer les opérations d’analyse spatiale.

Qualigéo permet de spécifier des règles topologiques qui lient les entités les unes aux autres. Par exemple, deux parcelles adjacentes ne peuvent pas se superposer et il ne peut y avoir de trou entre deux parcelles (autres que des voies non cadastrées).

La **<a name="kanchor15"></a>tessellation** met en avant les trous et chevauchements dans un jeu de données. La contrainte de tessellation [Laurini et Milleret-Raffort 1993] correspond à la partition totale d’un territoire par des polygones, sans espace ni chevauchement. La tessellation (ou mosaïque) est synonyme de couverture planaire. Les tuilages ou dallages sont des tessellations de motif régulier (rectangulaire en général).

La contrainte de tessellation de Qualigéo accepte que l’espace soit constitué d’éléments non connexes, totalement disjoints, comme des îles.

Dans Qualigéo, une contrainte de tessellation interdit donc le chevauchement de polygones ou la présence d’espaces fermés non remplis. Les trous dans les polygones sont acceptés si ces trous sont remplis par un autre polygone.

#### Définition de contrainte topologiques dans l’arbre

![](../../Ressources/Images/menu_contextuel_topologies.PNG)

La fonction **Ajouter une contrainte topologique** accessible via le menu contextuel permet de créer une nouvelle contrainte topologique. Lors du clic sur cet élément du menu, une nouvelle contrainte est ajoutée à la liste et l’interface de création de la contrainte est affichée.

![](../../Ressources/Images/contrainte_topo.png)

##### Caractéristiques des contraintes topologiques

L’interface **Caractéristiques de la contrainte topologique** permet de définir les règles topologiques qui lient les entités les unes aux autres. Par exemple, deux parcelles adjacentes ne peuvent pas se superposer et il ne peut y avoir de trous entre deux parcelles (autres que des voies non cadastrées).

L’utilisateur peut sélectionner la contrainte de tessellation pour intégrer un commentaire.

<span style="color: #943a99;">==> Erreur retournée : E0014 (Violation de la contrainte de tessellation : chevauchement. Superposition d’objets).</span>

<span style="color: #943a99;">==> Erreur retournée : E0015 (Violation de la contrainte de tessellation : espace. Espace entre objets).</span>

[En savoir plus sur les contraintes topologiques](../../04-ContraintesRessources/03.07.Contraintes_topologiques.md)

##### Attributs de regroupement

On peut définir ensuite des attributs de regroupements. Le paramètre **Attributs de regroupement** permet de regrouper les entités à tester en les divisant en groupes en fonction des valeurs d’un attribut. Le contrôle est effectué sur les entités ayant les mêmes valeurs d’attribut de regroupement. Deux entités superposées ayant des valeurs d’attributs différentes ne génèrent donc pas d’erreur, le contrôle n’est pas effectué. Deux entités se chevauchant avec la même valeur d’attribut de regroupement produiront une erreur lors du contrôle.

[En savoir plus sur les contraintes topologies et le regroupement d’attributs.](../../04-ContraintesRessources/03.07.Contraintes_topologiques.html#attributs-de-regroupement-et-contrainte-topologique)

Il peut ensuite être défini une règle de validation. Une règle de validation permet à l’application de valider des erreurs de tessellation. Ne sont considérés comme en erreur que les objets qui respectent la règle de validation.

[En savoir plus sur les contraintes topologiques et les règles de validation.](../../04-ContraintesRessources/03.07.Contraintes_topologiques.html#attributs-de-regroupement-et-contrainte-topologique)

#### Définition de contraintes topologiques dans la liste

En cliquant dans l’arbre, sur le nœud **Type d’entité** d’un schéma ![](../../Ressources/Images/clic_TE.png), la liste des types d’entité composant le schéma s’affiche dans la fenêtre de droite. La liste permet de visualiser tous les types d’entité et les contraintes définies dans le formulaire de création. L’onglet **Topologie** de la liste permet d’afficher la liste de toutes les contraintes topologiques des types d’entité du schéma en cours.

![](../../Ressources/Images/liste_contrainte_topo.png)
